/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package Celbercor;

import javax.crypto.*;

/** (Step 2) After the end client requests a session ticket, the
 * server replies with a message of this class, encrypted with the end
 * client's password key.  If the user name is unknown, the session
 * key and sealed ticket will both be null.  */

public class AuthenticationReplyMessage
  implements java.io.Serializable
{

  public AuthenticationReplyMessage( Ticket ticket,
				     SealedObject sealedTicket )
    {
      myTicket = ticket;
      mySealedTicket = sealedTicket;
    }

  /** This ticket will contain the end client's name and IP address,
   * the name of the ticket server, a session key for communicating
   * with the ticket server, and a time stamp.  */

  public Ticket getTicket()
    {
      return myTicket;
    }

  /** This is the same ticket, sealed under the ticket server's
   * password key.  It is needed for step 3.  */

  public SealedObject getSealedTicket()
    {
      return mySealedTicket;
    }

  private Ticket myTicket;
  private SealedObject mySealedTicket;
}
