/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package Celbercor;

import java.io.*;
import java.net.*;
import java.security.*;
import javax.crypto.*;
import javax.crypto.spec.*;

/** This is a base class for the main authentication server and the
 * ticket server.  Both use password lists and so on, and that
 * functionality is factored out into this base class.
 * 
 * @see Celbercor.AuthenticationServer
 * @see Celbercor.TicketServer */

public abstract class ServerBase
  implements Runnable
{

  /** Read a list of passwords from the given file.  This replaces any
   * existing passwords this server was using.  */

  public void readPasswords( String fileName )
    throws IOException
    {
      myPasswords = PasswordKeyList.readPasswords( fileName );
    }

  public void open( int port )
    throws IOException
    {
      myPort = port;
      mySocket = new ServerSocket( port );
    }

  /**
   * Handle one client.
   */

  public abstract void handleOneConnection( Socket s );

  /**
   * Just runs an infinite loop of <tt>handleOneConnection()</tt>.
   */

  public void run()
    {
      while( true )
	{
	  try
	    {
	      handleOneConnection( mySocket.accept() );
	    }
	  catch( IOException ex )
	    {
	      System.out.println( "Server socket has failed:\n" );
	      ex.printStackTrace();
	    }
	}
    }


  /**
   * @return the port this server is listening to
   */

  public int getPort()
    {
      return myPort;
    }

  /**
   * @return the password list this server is using
   */

  public PasswordKeyList getPasswords()
    {
      return myPasswords;
    }


  private int myPort;
  private ServerSocket mySocket;
  private PasswordKeyList myPasswords;

  
}
