/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom;

import java.io.*;
import java.security.*;
import Celbercor.*;
import ChatRoom.Tools.*;
import ChatRoom.Server.*;
import ChatRoom.Security.*;
import ChatRoom.Celbercor.*;

/** This <tt>main()</tt> function runs a secure chat room server that
 * understands the Celbercor authentication protocol.  */

public abstract class CelbercorServer
{
  /**
   * Start a secure server.  The arguments are:
   *
   * <pre>
   * java ChatRoom.CelbercorServer [<i>port</i>]
   * </pre>
   *
   * where <i>port</i> is the port number to listen to (default value
   * is {@link ChatRoomConstants#DEFAULT_PORT
   * <tt>ChatRoomConstants.DEFAULT_PORT</tt>}).*/

  public static void main( String args[] )
    {
      try
	{
	  EncryptionStandard.getInstance().initializeEncryptionLibrary();
	}
      catch( GeneralSecurityException ex )
	{
	  ex.printStackTrace();
	  System.exit(1);
	}

      int port = ChatRoomConstants.DEFAULT_PORT;

      if( args.length >= 1 )
	{
	  port = Integer.parseInt( args[0] );
	}

      ServerAuthentication sAuth =
	new ServerAuthenticationImpl( Constants.CHATROOM_NAME );

      if( !sAuth.initialize() )
	{
	  System.out.println( "Server initialization failed" );
	  System.exit(2);
	}

      SecureServer s = new SecureServer( sAuth );
      try
	{
	  s.open( port );
	}
      catch( IOException ex )
	{
	  System.out.println( "Could not open port" );
	  System.exit(3);
	}
      
      System.out.println( "Chat room server listening on port " + port );
      s.run();
    }
}
