/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom;

import java.io.*;
import java.security.*;
import FlamingSword.*;
import ChatRoom.Tools.*;
import ChatRoom.Server.*;
import ChatRoom.Security.*;
import ChatRoom.FlamingSword.*;

/** This <tt>main()</tt> function starts a chat server which uses the
 * Flaming Sword authentication protocol.  */

public abstract class FlamingSwordServer
{
  /**
   * Start a Flaming Sword Server.  The arguments are:
   *
   * <pre>
   * java ChatRoom.FlamingSwordServer <i>authFileName</i> [<i>port</i>]
   * </pre>
   *
   * where <i>authFileName</i> is the abbreviated name of a file
   * containing the authentication server's public key (<tt>.pub</tt>
   * will be appended to that name), and <i>port</i> is the port to
   * listent to (default value is
   * <tt>ChatRoomConstants.DEFAULT_PORT</tt>).  */

  public static void main( String args[] )
    {
      String authFileName = null;
      int port = ChatRoomConstants.DEFAULT_PORT;

      if( args.length < 1 )
	{
	  System.out.println( "Arguments: authFileName [port]" );
	}

      authFileName = args[0];

      if( args.length >= 2 )
	{
	  port = Integer.parseInt( args[1] );
	}

      try
	{
	  EncryptionStandard.getInstance().initializeEncryptionLibrary();
	}
      catch( GeneralSecurityException ex )
	{
	  ex.printStackTrace();
	  System.exit(2);
	}

      System.out.println( "--Will read authentication server key using: " 
			  + authFileName );

      ServerAuthentication sAuth =
	new ServerAuthenticationImpl( Constants.CHATROOM_NAME,
				      authFileName );


      if( !sAuth.initialize() )
	{
	  System.out.println( "Server initialization failed" );
	  System.exit(3);
	}

      SecureServer s = new SecureServer( sAuth );
      try
	{
	  s.open( port );
	}
      catch( IOException ex )
	{
	  System.out.println( "Could not open port" );
	  System.exit(4);
	}
      
      System.out.println( "Chat room server listening on port " + port );
      s.run();
    }
}
