/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Security;

import ChatRoom.Tools.*;

/** This class takes messages from another reader and rejects those
 * that don't have the right name.  (This is an example of the
 * decorator design pattern.)  */

public class CheckedReader
  implements Reader
{

  /** Construct a <tt>CheckedReader</tt> which only returns messages
   * with the given name.
   *
   * @param name name to check for
   * @param reader another reader to read from.
   */

  public CheckedReader( String name, Reader r )
    {
      myName = name;
      myReader = r;
    }

  public Message getNextMessage()
    {
      Message m;

      do
	{
	  m = myReader.getNextMessage();
	}
      while( m != null && !myName.equals(m.getName()) );

      return m;
    }

  private String myName;
  private Reader myReader;
}
