/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Security;

import java.io.*;
import java.security.*;
import ChatRoom.Tools.*;
import ChatRoom.Tools.Reader;
import ChatRoom.Tools.Writer;

/** This interface is used by clients to identify themselves to
 * servers that use some sort of security system.  */

public interface ClientAuthentication
{

  /** Initialize this authentication object.  (This is where you would
   * ask for passwords, etc.) 
   *
   * @return true if initialization suceeded, false if not (for
   * example, the user couldn't enter a valid password or some server
   * was down).
   * */

  public boolean initialize();

  /** Send some sort of verification data to the chat room server at
   * the given host and port.  Once this method has been called, you
   * receive a reader and writer that can communicate with the server
   * over an encrypted data stream.
   *
   * @return a reader and a writer, or <tt>null</tt> if the chat room
   * server did not accept verification of our identity.
   **/

  public RWPair sendVerification( String host, int port )
    throws IOException, GeneralSecurityException, ClassNotFoundException;

}
