/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Security;

import java.io.*;
import java.security.*;
import javax.crypto.*;
import Celbercor.*;
import ChatRoom.Tools.Reader;
import ChatRoom.Tools.Writer;
import ChatRoom.Tools.Message;

/** This writer class sends messages to a stream, encrypted using the
 * given cipher.  */

public class SealedObjectWriter
  implements Writer
{

  public SealedObjectWriter( Cipher c, ObjectOutput out )
    {
      myCipher = c;
      myOutput = out;
    }

  public void deliverMessage( Message m )
    throws IOException
    {
      try
	{
	  SealedObject s = new SealedObject( m, myCipher );
	  myOutput.writeObject( s );
	}
      catch( GeneralSecurityException ex )
	{
	  System.out.println( "Unexpected security exception:\n" );
	  ex.printStackTrace();
	}
    }

  private Cipher myCipher;
  private ObjectOutput myOutput;
  
}
