/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Security;

import java.io.*;
import java.net.*;
import java.security.*;
import ChatRoom.Client.*;
import ChatRoom.Tools.*;
import ChatRoom.Tools.Reader;
import ChatRoom.Tools.Writer;

/** This is just a static function that takes some of the dirty work
 * out of constructing a <tt>Client</tt> object with encrypted readers
 * and writers.  */

public abstract class SecureClient
{
  /** Create a socket and contact a secure chat room server at the
   * given host and IP port using the given authentication object.
   * Throw an exception if this is not possible.  You must call
   * <tt>initialize()</tt> on <tt>auth</tt> before passing it to this
   * function.
   *
   * @return a client object if all goes well, <tt>null</tt> if not.
   * */

  public static Client createViaInternet( String host, int port,
					  ClientAuthentication auth )
    throws UnknownHostException, IOException, GeneralSecurityException, 
    ClassNotFoundException
    {
      RWPair p = auth.sendVerification( host, port );
      if( p != null )
	{
	  Reader r = p.getReader();
	  Writer w = p.getWriter();
	  return new Client( r, w );
	}
      else
	{
	  return null;
	}
    }
}
