/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Security;

import java.io.*;
import java.net.*;
import ChatRoom.Tools.*;
import ChatRoom.Tools.Reader;
import ChatRoom.Tools.Writer;

/** This interface is used by chat room servers that talk securely to
 * clients.  */

public interface ServerAuthentication
{
  /** Initialize this authentication object.  (This is where you would
   * ask for passwords, etc.) 
   *
   * @return true if initialization suceeded, false if not (for
   * example, the user couldn't enter a valid password or some server
   * was down).
   * */

  public boolean initialize();

  /** Read some input and attempt to verify the identity of the client
   * on the other end of <tt>in</tt>.  Once this method has been
   * called, you get a reader and a writer that will handle the
   * encrypted data coming from and going to this client.
   *
   * @param s the socket that the client is talking to
   *
   * @return A pair (reader,writer) if succeeded, <tt>null</tt> if not.
   * */

  public RWPair verifyClient( Socket s );

}
