/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom.Server;

import ChatRoom.Tools.*;
import java.util.*;
import java.io.IOException;

/** This is the data class, used server-side to represent the actual
 * chat room.  Each client has an associated Writer object in the
 * server whish is stored in an instance of this class.  When the
 * server wants to send a message to all its clients, it uses the
 * deliverMessage() method.  This class is essentially just a list of
 * Writers. */

public class ClientList
{

  public synchronized void addClient( Writer c )
    {
      myClients.addElement( c );
    }

  public synchronized void removeClient( Writer c )
    {
      myClients.removeElement( c );
    }

  /** Send the message to all clients in this list. */

  public synchronized void deliverMessage( Message m )
    {
      Enumeration e = myClients.elements();
      Writer w;
      Vector toBeRemoved = new Vector();

      System.out.println( "Delivering message " + m );

      while( e.hasMoreElements() )
	{
	  w = (Writer)e.nextElement();
	  try
	    {
	      w.deliverMessage( m );
	    }
	  catch( IOException ex )
	    {
	      System.out.println( "Lost contact with one client." );
	      toBeRemoved.addElement( w );
	    }
	}

      e = toBeRemoved.elements();

      while( e.hasMoreElements() )
	{
	  myClients.removeElement( e.nextElement() );
	}
    }

  private Vector myClients = new Vector();
}
