/*
This file is part of ChatRoom.

Copyright (C) 1999 William Garrett Mitchener
E-mail: wmitchen@princeton.edu

ChatRoom is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

ChatRoom is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with ChatRoom; if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
package ChatRoom;

import ChatRoom.Server.*;
import ChatRoom.Tools.*;
import java.io.*;
import java.net.*;
import java.util.*;
import ChatRoom.Tools.Reader;
import ChatRoom.Tools.Writer;

/** This <tt>main()</tt> function starts a <tt>ThreadedServer</tt>.
 *
 * @see ChatRoom.Server.ThreadedServer
 * */

public abstract class ThreadedServer
{
  /**
   * Start a threaded server.  The optional arguments are as follows:
   *
   * <pre>
   * java ChatRoom.ThreadedServer [<i>port</i>]
   * </pre>
   * 
   * where <i>port</i> is the port to listen to (default value is
   * {@link ChatRoomConstants#DEFAULT_PORT
   * <tt>ChatRoomConstants.DEFAULT_PORT</tt>}).  */

  public static void main( String args[] )
    {
      int port = ChatRoomConstants.DEFAULT_PORT;
      ChatRoom.Server.ThreadedServer s = new ChatRoom.Server.ThreadedServer();

      if( args.length >=1 )
	{
	  port = new Integer( args[0] ).intValue();
	}

      System.out.println( "Chat room server listening on port " + port );

      try
	{
	  s.open( port );
	}
      catch( IOException ex )
	{
	  System.out.println( "Could not open server port." );
	  System.exit(1);
	}

      s.run();
      
    }
}
